@@ -1,5 +1,5 @@
 #!/bin/sh
-prefix=/usr
+prefix=/usr/share
 infodir=${prefix}/info
 cd ${infodir}
 for fn in gnugo.info ; do
